==> corhel-2.1.tar.gz: CORHEL-2.1/tools/corona/set.sh <==
#!/bin/csh
#---------------------------------------------------------------------------
# set.sh: Set environment variables to compile and run MAS computations.
#
# Usage: source ./set.sh [mode]
#     [mode] is either 'make' or 'run'.
#---------------------------------------------------------------------------

# Checking argument
if ($#argv != 1 || ($1 != 'make' && $1 != 'run')) then
  echo "set.sh: Set environment variables to compile and run MAS computations."
  echo ""
  echo "Usage: source ./set.sh [mode]"
  echo "    [mode] is either 'make' or 'run'."
  exit 0
endif

# Checking system platform
if (`uname` == 'Linux') then
  set compiler = "ifort"
  set system = "linux"
else if (`uname` == 'Darwin') then
  set compiler = "xlf"
  set system = "macosx"
else
  echo "ERROR: Unsupported platform"
  exit 1
endif

# Set directories
setenv CORONA_DIR "`pwd`"
setenv CORONA_INC "`pwd`/include"
setenv CORONA_BIN "`pwd`/bin/$system"
setenv CORONA_LIB "`pwd`/lib/$system"

# Rerun ranlib just in case after copying CORHEL-2.1
pushd lib/$system > /dev/null
foreach lib (*.a)
  ranlib $lib
end
popd > /dev/null


#--------------------------------------------------------------------------
# Things needed to be set for compilation.
#--------------------------------------------------------------------------
if ($1 == 'make') then

  # Checking fortran compiler
  set fortran = `which $compiler`
  if ($#fortran != 1) then
    echo "ERROR: $compiler is required, but not found"
    exit 1
  endif

  # Set environment variables
  setenv SYSTEM "$system"
  setenv F90 "$fortran"
  if ($compiler == 'ifort') then
    setenv F90_OPTS "-O3 -assume byterecl"
    setenv MAS_F90_OPTS "-w -r8"
    setenv LD_OPTS "-Vaxlib -static -Bstatic -pthread"
  else
    setenv F90_OPTS "-O3 -qstrict"
    setenv MAS_F90_OPTS "-w -qealsize=8 -qextname=etime"
    setenv LD_OPTS ""
  endif

  setenv LIBDF "-L$CORONA_LIB -lmfhdf -ldf -lz -lsz -ljpeg"
  setenv FITSIO "-lcfitsio"

  setenv PARSE_LIB_r4 "-I$CORONA_INC -L$CORONA_LIB -lzm_parse_r4"
  setenv PARSE_LIB_r8 "-I$CORONA_INC -L$CORONA_LIB -lzm_parse_r8"
  setenv SDS_LIB_r4 "-I$CORONA_INC -L$CORONA_LIB -lzm_sds_r4"
  setenv SDS_LIB_r8 "-I$CORONA_INC -L$CORONA_LIB -lzm_sds_r8"
  setenv PARSE_MOD_r4 "$CORONA_INC/number_types_r4.f $CORONA_INC/zm_parse_modules.f"
  setenv PARSE_MOD_r8 "$CORONA_INC/number_types_r8.f $CORONA_INC/zm_parse_modules.f"
  setenv SDS_MOD_r4 "$CORONA_INC/number_types_r4.f $CORONA_INC/zm_sds_modules.f"
  setenv SDS_MOD_r8 "$CORONA_INC/number_types_r8.f $CORONA_INC/zm_sds_modules.f"

endif


#--------------------------------------------------------------------------
# Things needed to be set for running execution.
#--------------------------------------------------------------------------
if ($1 == 'run') then

  # Set static and dynamic library path
  setenv LD_LIBRARY_PATH
  setenv LD_LIBRARY_PATH "$CORONA_LIB"

  if ($system == 'macosx') then
    setenv DYLD_LIBRARY_PATH
    setenv DYLD_LIBRARY_PATH "$CORONA_LIB"
  endif

endif

==> corhel-2.3.tar.gz: CORHEL-2.3/tools/corona/set.sh <==
#!/bin/csh
#---------------------------------------------------------------------------
# set.sh: Set environment variables to compile and run MAS computations.
#
# Usage: set.sh <make | run>
#---------------------------------------------------------------------------

# Checking argument
if ($#argv != 1 || ($1 != 'make' && $1 != 'run')) then
  echo "Usage: set.sh <make | run>"
  exit 1
endif

# Checking system platform
if (`uname` == 'Linux') then
  set compiler = "ifort"
  set system = "linux"
else if (`uname` == 'Darwin') then
  set compiler = "xlf"
  set system = "macosx"
else
  echo "ERROR: Unsupported platform"
  exit 1
endif

# Set directories
setenv CORONA_DIR "`pwd`"
setenv CORONA_INC "`pwd`/include"
setenv CORONA_BIN "`pwd`/bin/$system"
setenv CORONA_LIB "`pwd`/lib/$system"

# Rerun ranlib just in case after copying CORHEL distribution
pushd lib/$system > /dev/null
foreach lib (*.a)
  ranlib $lib
end
popd > /dev/null


#--------------------------------------------------------------------------
# Things needed to be set for compilation.
#--------------------------------------------------------------------------
if ($1 == 'make') then

  # Checking fortran compiler
  set fortran = `which $compiler`
  if ($#fortran != 1) then
    echo "ERROR: $compiler is required, but not found"
    exit 1
  endif

  # Set environment variables
  setenv SYSTEM "$system"
  setenv F90 "$fortran"
  if ($compiler == 'ifort') then
    setenv F90_OPTS "-O3 -assume byterecl"
    setenv MAS_F90_OPTS "-w -r8"
    setenv LD_OPTS "-Vaxlib -static -Bstatic -pthread"
  else
    setenv F90_OPTS "-O3 -qstrict"
    setenv MAS_F90_OPTS "-w -qealsize=8 -qextname=etime"
    setenv LD_OPTS ""
  endif

  setenv LIBDF "-L$CORONA_LIB -lmfhdf -ldf -lz -lsz -ljpeg"
  setenv FITSIO "-lcfitsio"

  setenv PARSE_LIB_r4 "-I$CORONA_INC -L$CORONA_LIB -lzm_parse_r4"
  setenv PARSE_LIB_r8 "-I$CORONA_INC -L$CORONA_LIB -lzm_parse_r8"
  setenv SDS_LIB_r4 "-I$CORONA_INC -L$CORONA_LIB -lzm_sds_r4"
  setenv SDS_LIB_r8 "-I$CORONA_INC -L$CORONA_LIB -lzm_sds_r8"
  setenv PARSE_MOD_r4 "$CORONA_INC/number_types_r4.f $CORONA_INC/zm_parse_modules.f"
  setenv PARSE_MOD_r8 "$CORONA_INC/number_types_r8.f $CORONA_INC/zm_parse_modules.f"
  setenv SDS_MOD_r4 "$CORONA_INC/number_types_r4.f $CORONA_INC/zm_sds_modules.f"
  setenv SDS_MOD_r8 "$CORONA_INC/number_types_r8.f $CORONA_INC/zm_sds_modules.f"

endif


#--------------------------------------------------------------------------
# Things needed to be set for running execution.
#--------------------------------------------------------------------------
if ($1 == 'run') then

  # Set static and dynamic library path
  setenv LD_LIBRARY_PATH
  setenv LD_LIBRARY_PATH "$CORONA_LIB"

  if ($system == 'macosx') then
    setenv DYLD_LIBRARY_PATH
    setenv DYLD_LIBRARY_PATH "$CORONA_LIB"
  endif

endif
